@@ -2,7 +2,7 @@
 from django import forms
 from django.forms.models import BaseInlineFormSet, inlineformset_factory
 from .models import *
-from dal import autocomplete
+#from dal import autocomplete
 from microsip_web.apps.main.forms import filtroarticulos_form
 
 class impuestos_articulos_form(forms.ModelForm):
