@@ -9,4 +9,6 @@ class BancoBase(models.Model):
 
     class Meta:
         db_table = u'bancos'
-        abstract = True
\ No newline at end of file
+        abstract = True
+        managed= False
+        app_label='models_base'
\ No newline at end of file
