@@ -15,7 +15,7 @@ class CajeroBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return self.nombre
 
 class CajaBase(models.Model):
@@ -31,7 +31,7 @@ class CajaBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return self.nombre 
 
 class CajaFoliosManager(models.Manager):
@@ -53,7 +53,7 @@ class CajaFoliosBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s'% (self.caja, self.documento_tipo, self.serie)
 
 class CajeroCajaManager(models.Manager):
@@ -72,7 +72,7 @@ class CajeroCajaBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s'% (self.cajero, self.caja )
 
 class FormaCobroBase(models.Model):
@@ -86,7 +86,7 @@ class FormaCobroBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return self.nombre
 
 class FormaCobroReferenciaBase(models.Model):
@@ -100,7 +100,7 @@ class FormaCobroReferenciaBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return self.nombre
 
 class CajaMovimientoBase(models.Model):
@@ -128,7 +128,7 @@ class CajaMovimientoBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return "%s"%self.id
 
 class CajaMovimientoFondoBase(models.Model):
@@ -143,5 +143,5 @@ class CajaMovimientoFondoBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return "%s"%self.id
\ No newline at end of file
